@@ -16,6 +16,7 @@
 
 import os
 import signal
+import sys
 
 from cdpcli.help import ExecutableNotFoundError
 from cdpcli.help import HelpCommand, WindowsHelpRenderer
@@ -41,7 +42,9 @@ class HelpSpyMixin(object):
 
 
 class FakePosixHelpRenderer(HelpSpyMixin, PosixHelpRenderer):
-    pass
+    def __init__(self, output_stream=sys.stdout):
+        HelpSpyMixin.__init__(self)
+        PosixHelpRenderer.__init__(self, output_stream)
 
 
 class FakeWindowsHelpRenderer(HelpSpyMixin, WindowsHelpRenderer):
@@ -95,13 +98,24 @@ class TestHelpPager(unittest.TestCase):
         self.assertEqual(self.renderer.get_pager_cmdline(),
                          pager_cmd.split())
 
-    def test_no_groff_exists(self):
+    def test_no_groff_or_mandoc_exists(self):
         renderer = FakePosixHelpRenderer()
         renderer.exists_on_path['groff'] = False
-        with self.assertRaisesRegexp(ExecutableNotFoundError,
-                                     'Could not find executable named: groff'):
+        renderer.exists_on_path['mandoc'] = False
+        expected_error = 'Could not find executable named: groff or mandoc'
+        with self.assertRaisesRegex(ExecutableNotFoundError, expected_error):
             renderer.render('foo')
 
+    @skip_if_windows('Requires POSIX system.')
+    def test_renderer_falls_back_to_mandoc(self):
+        renderer = FakePosixHelpRenderer()
+        renderer.exists_on_path['groff'] = False
+        renderer.exists_on_path['mandoc'] = True
+        renderer.mock_popen.communicate.return_value = ('rendered', '')
+        renderer.render('foo')
+        args, kargs = renderer.mock_popen.communicate.call_args_list[0]
+        self.assertIn(b'foo', kargs.get('input'))
+
     def test_shlex_split_for_pager_var(self):
         pager_cmd = '/bin/sh -c "col -bx | vim -c \'set ft=man\' -"'
         os.environ['PAGER'] = pager_cmd
@@ -121,6 +135,66 @@ class TestHelpPager(unittest.TestCase):
         renderer.render('foo')
         self.assertEqual(renderer.popen_calls[-1][0], (['more'],))
 
+    def test_render_environments_help(self):
+        renderer = FakePosixHelpRenderer()
+        renderer.exists_on_path['groff'] = True
+        renderer.mock_popen.communicate.return_value = ('rendered', '')
+        renderer.render('\n\n'
+                        '.. _cli:cdp environments:\n\n\n'
+                        '************\n'
+                        'environments\n'
+                        '************\n'
+                        '\n\n\n'
+                        ':subtitle: Cloudera Environments Service\n\n\n\n'
+                        ':version: 0.9.36\n\n\n\n'
+                        '===========\n'
+                        'Description\n'
+                        '===========\n'
+                        '\n'
+                        'CDP Environments Service description.\n'
+                        '\n'
+                        '=====================\n'
+                        'Available Subcommands\n'
+                        '=====================\n'
+                        '\n\n\n\n'
+                        '* create-environment\n\n')
+        args, kargs = renderer.mock_popen.communicate.call_args_list[0]
+        self.assertIn(b'Cloudera Environments Service', kargs.get('input'))
+        self.assertIn(b'Generated by docutils manpage writer', kargs.get('input'))
+
+    def test_render_environments_help_on_windows(self):
+        renderer = FakeWindowsHelpRenderer()
+        renderer.mock_popen.communicate.return_value = ('rendered', '')
+        renderer.render('\n\n'
+                        '.. _cli:cdp environments:\n\n\n'
+                        '************\n'
+                        'environments\n'
+                        '************\n'
+                        '\n\n\n'
+                        ':subtitle: Cloudera Environments Service\n\n\n\n'
+                        ':version: 0.9.36\n\n\n\n'
+                        '===========\n'
+                        'Description\n'
+                        '===========\n'
+                        '\n'
+                        'CDP Environments Service description.\n'
+                        '\n'
+                        '=====================\n'
+                        'Available Subcommands\n'
+                        '=====================\n'
+                        '\n\n\n\n'
+                        '* create-environment\n\n')
+        args, kargs = renderer.mock_popen.communicate.call_args
+        self.assertEqual(kargs, {'input': b'\n'
+                                          b'environments\n'
+                                          b'^^^^^^^^^^^^\n\n\n'
+                                          b'Description\n'
+                                          b'***********\n\n'
+                                          b'CDP Environments Service description.\n\n\n'
+                                          b'Available Subcommands\n'
+                                          b'*********************\n\n'
+                                          b'* create-environment\n'})
+
     @skip_if_windows("Ctrl-C not valid on windows.")
     def test_can_handle_ctrl_c(self):
         class CtrlCRenderer(FakePosixHelpRenderer):
@@ -159,6 +233,7 @@ class TestHelpCommand(TestHelpCommandBase):
         self.doc_generator_mock = mock.Mock()
         self.subcommand_mock = mock.Mock()
         self.renderer = mock.Mock()
+        self.parsed_globals = mock.Mock(deprecated=False)
 
         class SampleHelpCommand(HelpCommand):
             GeneratorClass = self.doc_generator_mock
@@ -171,19 +246,26 @@ class TestHelpCommand(TestHelpCommandBase):
         self.cmd.renderer = self.renderer
 
     def test_subcommand_call(self):
-        self.cmd(None, ['mycommand'], None)
-        self.subcommand_mock.assert_called_with([], None)
+        self.cmd(None, ['mycommand'], self.parsed_globals)
+        self.subcommand_mock.assert_called_with([], self.parsed_globals)
         self.assertFalse(self.doc_generator_mock.called)
 
     def test_regular_call(self):
-        self.cmd(None, [], None)
+        self.cmd(None, [], self.parsed_globals)
         self.assertFalse(self.subcommand_mock.called)
-        self.doc_generator_mock.assert_called_with(self.cmd)
+        self.doc_generator_mock.assert_called_with(self.cmd, show_hidden=False)
+        self.assertTrue(self.renderer.render.called)
+
+    def test_show_deprecated_call(self):
+        parsed_globals = mock.Mock(deprecated=True)
+        self.cmd(None, [], parsed_globals)
+        self.assertFalse(self.subcommand_mock.called)
+        self.doc_generator_mock.assert_called_with(self.cmd, show_hidden=True)
         self.assertTrue(self.renderer.render.called)
 
     def test_invalid_subcommand(self):
         with mock.patch('sys.stderr') as f:
             with self.assertRaises(SystemExit):
-                self.cmd(None, ['no-exist-command'], None)
+                self.cmd(None, ['no-exist-command'], self.parsed_globals)
         error_message = ''.join(arg[0][0] for arg in f.write.call_args_list)
         self.assertIn('Invalid choice', error_message)
